@@ -46,7 +46,7 @@ private:
         QDir dir(dirName);
 
         if (dir.exists(dirName)) {
-            Q_FOREACH (QFileInfo info, dir.entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst)) {
+            Q_FOREACH (const QFileInfo &info, dir.entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst)) {
                 if (info.isDir()) {
                     result = removeDir(info.absoluteFilePath());
                 } else {
@@ -124,7 +124,7 @@ private Q_SLOTS:
                 //qDebug() << "result " << it.id();
                 results << it.id();
             }
-            qSort(results);
+            std::sort(results.begin(), results.end());
             QCOMPARE(results.size(), 2);
             QCOMPARE(results.at(0), col1.id());
             QCOMPARE(results.at(1), col2.id());
@@ -139,7 +139,7 @@ private Q_SLOTS:
                 //qDebug() << "result " << it.id();
                 results << it.id();
             }
-            qSort(results);
+            std::sort(results.begin(), results.end());
             QCOMPARE(results.size(), 1);
             QCOMPARE(results.at(0), col2.id());
         }
