@@ -37,7 +37,8 @@ public Q_SLOTS:
     void defaults() override;
 
 private:
-    QCheckBox *mQueryCompletionCheckBox;
+    void configChanged();
+    QCheckBox *mQueryCompletionCheckBox = nullptr;
 };
 
 #endif
