@@ -77,7 +77,7 @@ public:
     bool haveChanges() const;
 
 private:
-    Xapian::Database *m_db;
+    Xapian::Database *m_db = nullptr;
     Xapian::WritableDatabase m_wDb;
 
     typedef QPair<Xapian::docid, Xapian::Document> DocIdPair;
@@ -85,7 +85,7 @@ private:
     QVector<uint> m_docsToRemove;
 
     std::string m_path;
-    bool m_writeOnly;
+    bool m_writeOnly = false;
 
     Xapian::WritableDatabase createWritableDb();
 };
